package ch.zhaw.gartenverwaltung.backgroundtasks;

import ch.zhaw.gartenverwaltung.Settings;
import ch.zhaw.gartenverwaltung.backgroundtasks.email.EMailSender;
import ch.zhaw.gartenverwaltung.io.PlantList;
import ch.zhaw.gartenverwaltung.io.TaskList;
import ch.zhaw.gartenverwaltung.models.Garden;
import ch.zhaw.gartenverwaltung.types.Task;

import javax.mail.MessagingException;
import java.io.IOException;
import java.time.LocalDate;

public class Notifier {
    private final TaskList taskList;
    private final Garden garden;
    private final PlantList plantList;
    private final EMailSender eMailSender = new EMailSender();

    public Notifier(TaskList taskList, Garden garden, PlantList plantList) {
        this.taskList = taskList;
        this.garden = garden;
        this.plantList = plantList;
    }

    private void sendNotification(Task task) throws MessagingException {
        String messageSubject = String.format(Settings.getInstance().getMailNotificationSubjectTemplate(), task.getName());
        String messageText = String.format(Settings.getInstance().getMailNotificationTextTemplate(), task.getName(), task.getNextExecution(), task.getDescription());
        //TODO create Exception for email sent fail
        eMailSender.sendMails(Settings.getInstance().getMailNotificationReceivers(), messageSubject, messageText);
    }

    public void sendNotifications() throws IOException, MessagingException {
        System.out.println("sending Notifications");
        for (Task task : taskList.getTaskList(LocalDate.MIN, LocalDate.MAX)) {
            if (task.getNextNotification() != null && task.getNextNotification().isBefore(LocalDate.now().minusDays(1))) {
                sendNotification(task);
                task.setNextNotification(LocalDate.now().plusDays(1));
            }
        }
    }
}
